@@ -131,7 +131,7 @@ public:
         }
     }
 
-    void emitCompletionSignal() Q_DECL_OVERRIDE;
+    void emitCompletionSignal() override;
 };
 
 class CreationChange : public Change
@@ -153,7 +153,7 @@ public:
         }
     }
 
-    void emitCompletionSignal() Q_DECL_OVERRIDE;
+    void emitCompletionSignal() override;
 
     Akonadi::Collection mUsedCol1lection;
 };
@@ -177,7 +177,7 @@ public:
         }
     }
 
-    void emitCompletionSignal() Q_DECL_OVERRIDE;
+    void emitCompletionSignal() override;
 
     QVector<Akonadi::Item::Id> mItemIds;
 };
@@ -240,7 +240,7 @@ public:
     {
         if (change->type == IncidenceChanger::ChangeTypeDelete) {
             DeletionChange::Ptr deletion = change.staticCast<DeletionChange>();
-            foreach (Akonadi::Item::Id id, deletion->mItemIds) {
+            for (Akonadi::Item::Id id : qAsConst(deletion->mItemIds)) {
                 Q_ASSERT(!m_itemIdsInOperation.contains(id));
                 m_itemIdsInOperation.insert(id);
             }
